Class: AMF::Messages::RemotingMessage
- Inherits:
-
AbstractMessage
- Object
- AbstractMessage
- AMF::Messages::RemotingMessage
- Defined in:
- lib/amf/messages.rb
Overview
Maps to flex.messaging.messages.RemotingMessage
Instance Attribute Summary collapse
-
#operation ⇒ Object
The name of the method to be called.
-
#parameters ⇒ Object
The arguments to call the method with.
-
#source ⇒ Object
The name of the service to be called including package name.
Attributes inherited from AbstractMessage
#body, #client_id, #destination, #headers, #message_id, #time_to_live, #timestamp
Instance Method Summary collapse
-
#initialize ⇒ RemotingMessage
constructor
A new instance of RemotingMessage.
Methods inherited from AbstractMessage
Constructor Details
#initialize ⇒ RemotingMessage
Returns a new instance of RemotingMessage.
47 48 49 50 51 52 53 54 55 |
# File 'lib/amf/messages.rb', line 47 def initialize @client_id = rand_uuid @destination = nil = rand_uuid = Time.new.to_i*100 @time_to_live = 0 @headers = {} @body = nil end |
Instance Attribute Details
#operation ⇒ Object
The name of the method to be called
42 43 44 |
# File 'lib/amf/messages.rb', line 42 def operation @operation end |
#parameters ⇒ Object
The arguments to call the method with
45 46 47 |
# File 'lib/amf/messages.rb', line 45 def parameters @parameters end |
#source ⇒ Object
The name of the service to be called including package name
39 40 41 |
# File 'lib/amf/messages.rb', line 39 def source @source end |